RtcPin

Trait RtcPin 

pub trait RtcPin: Pin {
    // Required method
    fn rtc_number(&self) -> u8;
}
Available on crate feature unstable only.
Trait implemented by RTC pins

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Required Methods

fn rtc_number(&self) -> u8

RTC number of the pin

Implementors

Source

impl RtcPin for GPIO7<'_>

Source

impl RtcPin for GPIO8<'_>

Source

impl RtcPin for GPIO9<'_>

Source

impl RtcPin for GPIO10<'_>

Source

impl RtcPin for GPIO11<'_>

Source

impl RtcPin for GPIO12<'_>

Source

impl RtcPin for GPIO13<'_>

Source

impl RtcPin for GPIO14<'_>

Source

impl RtcPin for AnyPin<'_>